@@ -54,7 +54,7 @@ class IPLoggerApp(BaseParallelApplication):
         except BaseException:
             self.log.error("Couldn't start the LogWatcher", exc_info=True)
             self.exit(1)
-        self.log.info("Listening for log messages on %r" % self.watcher.url)
+        self.log.info(f"Listening for log messages on {self.watcher.url!r}")
 
     def start(self):
         self.watcher.start()
