@@ -612,7 +612,7 @@ class IPEngine(BaseParallelApplication):
 
         def url(key):
             """get zmq url for given channel"""
-            return str(info["interface"] + ":%i" % info[key])
+            return f"{info['interface']}:{info[key]}"
 
         def urls(key):
             return [f'{info["interface"]}:{port}' for port in info[key]]
@@ -758,6 +758,8 @@ class IPEngine(BaseParallelApplication):
             if self.use_mpi and self.init_mpi:
                 app.exec_lines.insert(0, self.init_mpi)
             app.init_profile_dir()
+            app.init_gui_pylab()
+            app.init_extensions()
             app.init_code()
 
             # redirect output at the end, only after start is called
@@ -777,7 +779,7 @@ class IPEngine(BaseParallelApplication):
             content['hb_period'],
             identity,
         )
-        self.log.info("Completed registration with id %i" % self.id)
+        self.log.info("Completed registration with id %i", self.id)
 
     def start_nanny(self, control_url):
         self.log.info("Starting nanny")
@@ -809,7 +811,7 @@ class IPEngine(BaseParallelApplication):
             self._hb_listener = zmqstream.ZMQStream(mon, self.loop)
             self._hb_listener.on_recv(self._report_ping)
 
-            hb_monitor = "tcp://%s:%i" % (localhost(), mport)
+            hb_monitor = f"tcp://{localhost()}:{mport}"
 
         heart = Heart(
             hb_ping,
